searchNodes=[{"doc":"Implements a timers queue based on gb_trees. The queue keys are a two-tuple composed of the timestamp of an entry and an unique integer. No erlang timers or processes are used, as the queue is only a data structure. The advantage is that the queue can be persisted on storage and keep working after restarting the runtime. The queue maintain its own list of unique integers to avoir relying on BEAM unique integers as they are reset on restart. The main drawback is that the queue entries must be manually checked for expired timers.","ref":"TimeQueue.html","title":"TimeQueue","type":"module"},{"doc":"Deletes an entry from the queue and returns the new queue. It accepts a time reference or a full entry. When an entry is given, its time reference will be used to find the entry to delete, meaning the queue entry will be deleted even if the value of the passed entry was tampered. The function does not fail if the entry cannot be found and simply returns the queue as-is.","ref":"TimeQueue.html#delete/2","title":"TimeQueue.delete/2","type":"function"},{"doc":"Adds a new entry to the queue with a TTL and the current system time as now/0. See enqueue/4.","ref":"TimeQueue.html#enqueue/3","title":"TimeQueue.enqueue/3","type":"function"},{"doc":"Adds a new entry to the queue with a TTL relative to the given timestamp in milliseconds. Returns {:ok, tref, new_queue} where tref is a timer reference.","ref":"TimeQueue.html#enqueue/4","title":"TimeQueue.enqueue/4","type":"function"},{"doc":"Adds a new entry to the queue with an absolute timestamp. Returns {:ok, tref, new_queue} where tref is a timer reference.","ref":"TimeQueue.html#enqueue_abs/3","title":"TimeQueue.enqueue_abs/3","type":"function"},{"doc":"Creates an empty time queue. iex&gt; tq = TimeQueue.new() iex&gt; TimeQueue.peek(tq) :empty","ref":"TimeQueue.html#new/0","title":"TimeQueue.new/0","type":"function"},{"doc":"This function is used internally to determine the current time when it is not given in the arguments to enqueue/3, pop/1 and peek/1. It is a simple alias to :erlang.system_time(:millisecond). TimeQueue does not use monotonic time since it already manages its own unique identifiers for queue entries.","ref":"TimeQueue.html#now/0","title":"TimeQueue.now/0","type":"function"},{"doc":"Returns the next event of the queue with the current system time as now/0. See peek/2.","ref":"TimeQueue.html#peek/1","title":"TimeQueue.peek/1","type":"function"},{"doc":"Returns the next event of the queue according to the given current time in milliseconds. Possible return values are: :empty {:ok, entry} if the timestamp of the first entry is &lt;= to the given current time. {:delay, ms} if the timestamp of the first entry is &gt; to the given current time. The remaining amount of milliseconds is returned. Example iex&gt; {:ok, _tref, tq} = TimeQueue.new() |&gt; TimeQueue.enqueue(100, :hello, _now = 0) iex&gt; TimeQueue.peek(tq, _now = 20) {:delay, 80} iex&gt; {:ok, _} = TimeQueue.peek(tq, _now = 100)","ref":"TimeQueue.html#peek/2","title":"TimeQueue.peek/2","type":"function"},{"doc":"Extracts the next event of the queue with the current system time as now/0. See pop/2.","ref":"TimeQueue.html#pop/1","title":"TimeQueue.pop/1","type":"function"},{"doc":"Extracts the next event of the queue according to the given current time in milliseconds. Possible return values are: :empty {:ok, entry, new_queue} if the timestamp of the first entry is &lt;= to the given current time. The entry is deleted from new_queue. {:delay, ms} if the timestamp of the first entry is &gt; to the given current time. The remaining amount of milliseconds is returned. Example iex&gt; {:ok, _tref, tq} = TimeQueue.new() |&gt; TimeQueue.enqueue(100, :hello, _now = 0) iex&gt; TimeQueue.pop(tq, _now = 20) {:delay, 80} iex&gt; {:ok, _, _} = TimeQueue.pop(tq, _now = 100)","ref":"TimeQueue.html#pop/2","title":"TimeQueue.pop/2","type":"function"},{"doc":"Returns the numer of entries in the queue.","ref":"TimeQueue.html#size/1","title":"TimeQueue.size/1","type":"function"},{"doc":"Returns the time reference of an queue entry. This reference is used as a key to identify a unique entry. iex&gt; tq = TimeQueue.new() iex&gt; {:ok, tref, tq} = TimeQueue.enqueue(tq, 10, :my_value) iex&gt; Process.sleep(10) iex&gt; {:ok, entry} = TimeQueue.peek(tq) iex&gt; tref == TimeQueue.tref(entry) true","ref":"TimeQueue.html#tref/1","title":"TimeQueue.tref/1","type":"function"},{"doc":"Returns the value of an queue entry. iex&gt; tq = TimeQueue.new() iex&gt; {:ok, _, tq} = TimeQueue.enqueue(tq, 10, :my_value) iex&gt; Process.sleep(10) iex&gt; {:ok, entry} = TimeQueue.peek(tq) iex&gt; TimeQueue.value(entry) :my_value","ref":"TimeQueue.html#value/1","title":"TimeQueue.value/1","type":"function"},{"doc":"","ref":"TimeQueue.html#t:enqueue_return/1","title":"TimeQueue.enqueue_return/1","type":"type"},{"doc":"","ref":"TimeQueue.html#t:entry/0","title":"TimeQueue.entry/0","type":"opaque"},{"doc":"","ref":"TimeQueue.html#t:id/0","title":"TimeQueue.id/0","type":"opaque"},{"doc":"","ref":"TimeQueue.html#t:pop_return/1","title":"TimeQueue.pop_return/1","type":"type"},{"doc":"","ref":"TimeQueue.html#t:t/0","title":"TimeQueue.t/0","type":"opaque"},{"doc":"","ref":"TimeQueue.html#t:timespec/0","title":"TimeQueue.timespec/0","type":"type"},{"doc":"","ref":"TimeQueue.html#t:timespec_unit/0","title":"TimeQueue.timespec_unit/0","type":"type"},{"doc":"","ref":"TimeQueue.html#t:timestamp_ms/0","title":"TimeQueue.timestamp_ms/0","type":"type"},{"doc":"","ref":"TimeQueue.html#t:tref/0","title":"TimeQueue.tref/0","type":"opaque"},{"doc":"","ref":"TimeQueue.html#t:ttl/0","title":"TimeQueue.ttl/0","type":"type"}]